@@ -132,9 +132,9 @@ class SaltTestingParser(optparse.OptionParser):
             self.output_options_group.add_option(
                 '-x',
                 '--xml',
+                '--xml-out',
                 dest='xml_out',
                 default=False,
-                action='store_true',
                 help='XML test runner output(Output directory: {0})'.format(
                     self.xml_output_dir
                 )
@@ -205,18 +205,16 @@ class SaltTestingParser(optparse.OptionParser):
             if not os.path.isdir(self.xml_output_dir):
                 os.makedirs(self.xml_output_dir)
             print(
-                'Generated XML reports will be stored on {0!r}'.format(
-                    self.xml_output_dir
-                )
+                'Generated unit test XML reports will be stored '
+                'at {0!r}'.format(self.xml_output_dir)
             )
 
         if self.html_output_dir is not None and self.options.html_out:
             if not os.path.isdir(self.html_output_dir):
                 os.makedirs(self.html_output_dir)
             print(
-                'Generated HTML reports will be stored on {0!r}'.format(
-                    self.html_output_dir
-                )
+                'Generated unit test HTML reports will be stored '
+                'at {0!r}'.format(self.html_output_dir)
             )
 
         self.validate_options()
@@ -300,12 +298,13 @@ class SaltTestingParser(optparse.OptionParser):
                 if os.path.isdir(path):
                     shutil.rmtree(path)
 
-    def run_suite(self, path, display_name, suffix='[!_]*.py'):
+    def run_suite(self, path, display_name, suffix='[!_]*.py',
+                  load_from_name=False):
         '''
         Execute a unit test suite
         '''
         loader = TestLoader()
-        if self.options.name:
+        if load_from_name:
             tests = loader.loadTestsFromName(display_name)
         else:
             tests = loader.discover(path, suffix, self.testsuite_directory)
@@ -315,7 +314,11 @@ class SaltTestingParser(optparse.OptionParser):
 
         if self.options.xml_out:
             runner = xmlrunner.XMLTestRunner(
-                output=self.xml_output_dir).run(tests)
+                stream=sys.stdout,
+                output=self.xml_output_dir,
+                verbosity=self.options.verbosity
+            ).run(tests)
+            self.testsuite_results.append((header, runner))
         elif self.options.html_out:
             runner = HTMLTestRunner(
                 stream=open(
@@ -332,6 +335,7 @@ class SaltTestingParser(optparse.OptionParser):
             self.testsuite_results.append((header, runner))
         else:
             runner = TextTestRunner(
+                stream=sys.stdout,
                 verbosity=self.options.verbosity).run(tests)
             self.testsuite_results.append((header, runner))
         return runner.wasSuccessful()
@@ -429,12 +433,6 @@ class SaltTestingParser(optparse.OptionParser):
         call SaltTestingParser.post_execution_cleanup(self) from the overridden
         method.
         '''
-        if self.options.clean is True:
-            for path in (self.xml_output_dir, self.html_output_dir):
-                if path is None:
-                    continue
-                if os.path.isdir(path):
-                    shutil.rmtree(path)
 
     def finalize(self, exit_code=0):
         '''
